package com.xunmei.core.access.mapper;


import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.xunmei.core.access.domain.TMonitoringRetrievalPlan;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

/**
 * 监控调阅计划Mapper接口
 *
 * @author xunmei
 * @date 2023-08-24
 */
@Mapper
public interface TMonitoringRetrievalPlanMapper extends BaseMapper<TMonitoringRetrievalPlan> {
    /**
     * 查询监控调阅计划
     *
     * @param id 监控调阅计划主键
     * @return 监控调阅计划
     */
     TMonitoringRetrievalPlan selectTMonitoringRetrievalPlanById(Long id);

    /**
     * 查询监控调阅计划列表
     *
     * @param tMonitoringRetrievalPlan 监控调阅计划
     * @return 监控调阅计划集合
     */
     List<TMonitoringRetrievalPlan> selectTMonitoringRetrievalPlanList(TMonitoringRetrievalPlan tMonitoringRetrievalPlan);

    /**
     * 新增监控调阅计划
     *
     * @param tMonitoringRetrievalPlan 监控调阅计划
     * @return 结果
     */
     int insertTMonitoringRetrievalPlan(TMonitoringRetrievalPlan tMonitoringRetrievalPlan);

    /**
     * 修改监控调阅计划
     *
     * @param tMonitoringRetrievalPlan 监控调阅计划
     * @return 结果
     */
     int updateTMonitoringRetrievalPlan(TMonitoringRetrievalPlan tMonitoringRetrievalPlan);

    /**
     * 删除监控调阅计划
     *
     * @param id 监控调阅计划主键
     * @return 结果
     */
     int deleteTMonitoringRetrievalPlanById(Long id);

    /**
     * 批量删除监控调阅计划
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
     int deleteTMonitoringRetrievalPlanByIds(Long[] ids);
}
